package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.PBEParametersGenerator;
import cn.com.infosec.crypto.params.KeyParameter;
import cn.com.infosec.crypto.params.ParametersWithIV;
import javax.crypto.interfaces.PBEKey;
import javax.crypto.spec.PBEKeySpec;

public class JCEPBEKey implements PBEKey {
   String algorithm;
   DERObjectIdentifier oid;
   int type;
   int digest;
   int keySize;
   int ivSize;
   CipherParameters param;
   PBEKeySpec pbeKeySpec;
   boolean tryWrong = false;

   public JCEPBEKey(String algorithm, DERObjectIdentifier oid, int type, int digest, int keySize, int ivSize, PBEKeySpec pbeKeySpec, CipherParameters param) {
      this.algorithm = algorithm;
      this.oid = oid;
      this.type = type;
      this.digest = digest;
      this.keySize = keySize;
      this.ivSize = ivSize;
      this.pbeKeySpec = pbeKeySpec;
      this.param = param;
   }

   public String getAlgorithm() {
      return this.algorithm;
   }

   public String getFormat() {
      return "RAW";
   }

   public byte[] getEncoded() {
      CipherParameters var1;
      if ((var1 = this.param) != null) {
         return (var1 instanceof ParametersWithIV ? (KeyParameter)((ParametersWithIV)var1).getParameters() : (KeyParameter)var1).getKey();
      } else {
         return this.type == 2 ? PBEParametersGenerator.PKCS12PasswordToBytes(this.pbeKeySpec.getPassword()) : PBEParametersGenerator.PKCS5PasswordToBytes(this.pbeKeySpec.getPassword());
      }
   }

   int getType() {
      return this.type;
   }

   int getDigest() {
      return this.digest;
   }

   int getKeySize() {
      return this.keySize;
   }

   int getIvSize() {
      return this.ivSize;
   }

   CipherParameters getParam() {
      return this.param;
   }

   public char[] getPassword() {
      return this.pbeKeySpec.getPassword();
   }

   public byte[] getSalt() {
      return this.pbeKeySpec.getSalt();
   }

   public int getIterationCount() {
      return this.pbeKeySpec.getIterationCount();
   }

   public DERObjectIdentifier getOID() {
      return this.oid;
   }

   void setTryWrongPKCS12Zero(boolean tryWrong) {
      this.tryWrong = tryWrong;
   }

   boolean shouldTryWrongPKCS12() {
      return this.tryWrong;
   }
}
